#!/bin/bash

# Runs the TimeStampVerifier.

request=req.tsq
response=resp.tsr
chain=chain.txt
root=rootcert.crt
crl=crl.txt

class=de.dfncert.timestampverifier.TimeStampVerifier
libs=libs/bcpkix-jdk15on-152.jar:libs/bcprov-jdk15on-152.jar

if [ ! -f "$request" ]; then
    echo Creating new dummy request in $request
    echo "Stamp me" | openssl ts -query -cert > "$request"
fi

# Fetch response
echo Fetching response ...
wget -nv -O "$response" http://zeitstempel.dfn.de --post-file "$request"

if [ ! -f "$chain" ]; then
    echo Fetching chain ...
    wget -nv -O "$chain" https://pki.pca.dfn.de/global-services-ca/pub/cacert/chain.txt
fi

if [ ! -f "$root" ]; then
    echo Fetching root certificate ...
    wget -nv -O "$root" https://pki.pca.dfn.de/global-services-ca/pub/cacert/rootcert.crt
    echo $root is used as trusted root certificate.
fi

echo Fetching CRLs ...
wget -nv -O - http://crl.sbca.telesec.de/rl/DT_ROOT_CA_2.crl \
        | openssl crl -inform DER > "$crl"
wget -nv -O - http://cdp.pca.dfn.de/global-root-ca/pub/crl/cacrl.pem >> "$crl"
wget -nv -O - https://pki.pca.dfn.de/global-services-ca/pub/crl/cacrl.pem >> "$crl"
    
java -cp $libs:. $class "$request" "$response" "$chain" "$root" "$crl"
